package sklep.alternatywne_dostepy_do_bazy;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import jakarta.persistence.EntityManager;
import jakarta.persistence.TypedQuery;
import sklep.model.Product;

@Controller
@RequestMapping("/alt2/products")
public class ProductController_v2 {
    @Autowired
    private EntityManager em;

    @GetMapping(produces = "text/plain;charset=UTF-8")
    @ResponseBody
    public String readAll() {
        List<Product> products = em.createNamedQuery("Product.findAll", Product.class).getResultList();
        StringBuilder sb = new StringBuilder("Lista produktów:\n");
        for(Product product : products) {
            sb.append(" * ")
                    .append(product.getProductName())
                    .append(" za cenę ")
                    .append(product.getPrice())
                    .append('\n');
        }
        return sb.toString();
    }

    @GetMapping(path = "/{id}", produces = "text/plain;charset=UTF-8")
    @ResponseBody
    public String readOne(@PathVariable("id") Integer productId) {
        Product product = em.find(Product.class, productId);
        StringBuilder sb = new StringBuilder();
        if(product != null) {
            sb.append("Znaleziony produkt:\n")
                    .append(product.getProductName())
                    .append(" za cenę ")
                    .append(product.getPrice())
                    .append('\n');
        } else {
            sb.append("Nie ma produktu o numerze ").append(productId);
        }
        return sb.toString();
    }

    @GetMapping(path = "/szukaj", produces = "text/plain;charset=UTF-8")
    @ResponseBody
    public String szukaj(String name) {
        TypedQuery<Product> query = em.createQuery("SELECT p FROM Product p WHERE productName = :nazwa", Product.class);
        query.setParameter("nazwa", name);
        Product product = query.getSingleResult();
        StringBuilder sb = new StringBuilder();
        if(product != null) {
            sb.append("Znaleziony produkt:\n")
                    .append(product.getProductName())
                    .append(" za cenę ")
                    .append(product.getPrice())
                    .append('\n');
        } else {
            sb.append("Nie ma produktu o nazwie ").append(name);
        }
        return sb.toString();
    }

}
